.. _api-models:

======
Models
======

.. automodule:: projector.models

Return to :ref:`api`.

.. _api-models-core:

.. model:: Project

Project
=======

.. autoclass:: projector.models.Project
   :members:

See also :manager:`ProjectManager`.

.. model:: Config

Config
======

.. autoclass:: projector.models.Config
   :members:

.. _api-models-workflow:

.. model:: Milestone

Milestone
=========

.. autoclass:: projector.models.Milestone
   :members:

.. model:: Component

Component
=========

.. autoclass:: projector.models.Component
   :members:

.. model:: Priority

Priority
========

.. autoclass:: projector.models.Priority
   :members:

.. model:: Status

Status
======

.. autoclass:: projector.models.Status
   :members:

.. model:: Transition

Transition
==========

.. autoclass:: projector.models.Transition
   :members:

.. model:: TaskType

TaskType
========

.. autoclass:: projector.models.TaskType
   :members:


.. model:: AbstractTask

AbstractTask
============

.. autoclass:: projector.models.Task
   :members:

.. model:: TaskRevision

TaskRevision
============

.. autoclass:: projector.models.TaskRevision
   :members:

.. model:: Task

Task
====

.. autoclass:: projector.models.Task
   :members:

.. _api=models=auth:

.. model:: Membership

Membership
==========

.. autoclass:: projector.models.Membership
   :members:


.. model:: Team

Team
====

.. autoclass:: projector.models.Team
   :members:

.. autoclass:: projector.managers.TeamManager
   :members:

.. model:: UserProfile

UserProfile
===========

.. autoclass:: projector.models.UserProfile
   :members:


